#
# spec file for package sequoia-sq
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           sequoia-sq
Version:        0.33.0
Release:        bp156.1.3
Summary:        Command-line frontend for Sequoia
Group:          Productivity/Security
License:        GPL-2.0-only
URL:            https://sequoia-pgp.org/
Source0:        sequoia-sq-%{version}.tar.xz
Source1:        vendor.tar.xz
BuildRequires:  capnproto
BuildRequires:  cargo-packaging
BuildRequires:  clang-devel
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(nettle)
BuildRequires:  pkgconfig(openssl)
BuildRequires:  pkgconfig(sqlite3)
ExclusiveArch:  %{rust_tier1_arches}
Conflicts:      ispell-sq

%global crate sequoia-sq

%description
Sequoia is an OpenPGP implementation. Sequoia-sq is the frontend
for the sequoia library and it is also an example of how to use various
aspects of Sequoia.


%package bash-completion
Summary:        Bash completion for %{name}
Group:          Productivity/Security
BuildArch:      noarch
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)

%description bash-completion
Bash command line completion support for %{name}

%package        fish-completion
Summary:        Fish Completion for %{name}
Group:          Productivity/Security
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description    fish-completion
Fish command-line completion support for %{name}.

%package        zsh-completion
Summary:        Zsh Completion for %{name}
Group:          Productivity/Security
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description    zsh-completion
Zsh command-line completion support for %{name}.


%prep
%autosetup -a1 -n sequoia-sq-%{version}
mkdir -p .cargo

%build
%{cargo_build}

%install
%{cargo_install}
# install man pages
mkdir -p %{buildroot}/%{_mandir}/man1
cp -pav target/release/build/%{crate}-*/out/man-pages/sq*.1 %{buildroot}/%{_mandir}/man1/
# install shell completions
install -Dpm 0644 target/release/build/%{crate}-*/out/shell-completions/sq.bash %{buildroot}%{_datadir}/bash-completion/completions/sq.bash
install -Dpm 0644 target/release/build/%{crate}-*/out/shell-completions/sq.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/sq.fish
install -Dpm 0644 target/release/build/%{crate}-*/out/shell-completions/_sq %{buildroot}%{_datadir}/zsh/site-functions/_sq

%check
%{cargo_test}

%files
%license LICENSE.txt
%doc README.md
%doc NEWS
%{_bindir}/sq
%{_mandir}/man1/sq*

%files bash-completion
%license LICENSE.txt
%{_datadir}/bash-completion/completions/sq.bash

%files fish-completion
%license LICENSE.txt
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/sq.fish

%files zsh-completion
%license LICENSE.txt
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_sq

%changelog
* Mon Feb 26 2024 Jan Engelhardt <jengelh@inai.de>
- Ensure neutrality of descriptions.
* Thu Feb 22 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Add conflict with ispell-sq
* Thu Feb 22 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Add shell completions
* Tue Feb 20 2024 Felix Niederwanger <felix.niederwanger@suse.com>
- Add man pages and doc files
* Thu Feb 15 2024 felix.niederwanger@suse.de
- Use the sequoia-sq repository instead of the old sequoia with tags therein
- Add sqlite dependency
- Remove cargo_config
- Update to version 0.33.0:
  * Release 0.33.0.
  * Allow updating textwrap to 0.16.
  * Bump all dependencies.
  * Improve build and installation instructions.
  * Update NEWS.
  * Fix markup.
  * Update h2 to fix RUSTSEC-2024-0003.
  * Implement sq version, drop --version, move output-version there.
  * Add sq toolbox, move the armor and packet subcommands there.
  * Move sq import and export to sq cert.
* Thu Feb 15 2024 felix.niederwanger@suse.de
- Update to version 0.33.0:
  * Release 0.33.0.
  * Allow updating textwrap to 0.16.
  * Bump all dependencies.
  * Improve build and installation instructions.
  * Update NEWS.
  * Fix markup.
  * Update h2 to fix RUSTSEC-2024-0003.
  * Implement sq version, drop --version, move output-version there.
  * Add sq toolbox, move the armor and packet subcommands there.
  * Move sq import and export to sq cert.
* Thu Feb  8 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Disable update of vendored dependencies due to build errors
* Thu Feb  8 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Update licence (GPLv2-only)
* Wed Feb  7 2024 Felix Niederwanger <felix.niederwanger@suse.de>
- Update the service file:
  * Change version schema to not include the git commit
  * Remove unnecessary cargo audit
  * Use obscpio as storage format
* Wed Feb  7 2024 felix.niederwanger@suse.de
- Update to version 0.28.0~git0.82eb0d7:
  * sq: Release 0.28.0.
  * sq: Fix usage generation.
  * sq: Avoid deprecated chrono interfaces.
  * sq: Update manpages.
  * sq: Fix features.
  * openpgp: Add streaming decryptor tests using passwords.
  * openpgp: Fix salt generation in impl Arbitrary for S2K.
  * openpgp: Enable test.
  * openpgp: Fix documentation.
  * openpgp: Don't check subpacket area length when parsing.
* Wed Jul 27 2022 adam@mizerski.pl
- Update to version 0.27.0~git0.fd8912e4:
  * sq: Release 0.27.0.
  * sq: allow choosing output format and version via the environment
  * sq: update subplot to test JSON output for 'sq keyring list' works
  * sq: add JSON output for 'sq keyring list'
  * sq: add dependency on serde and serde-json
  * sq: add global options --output-format and --output-version
  * sq: add data types for output format and version of output format
  * sq: Update manpages.
  * net: Release 0.25.0.
  * sq: Implement 'key userid strip'.
* Sat Apr 23 2022 adam@mizerski.pl
- Update to version 0.26.0~git0.103faed4:
  * sq: Release 0.26.0.
  * openpgp: Open NEWS entry for 1.9.0.
  * openpgp: Release 1.8.0.
  * openpgp: Disable doctest if padding is not available.
  * openpgp: Fix test.
  * openpgp: Fix warnings when building without compression features.
  * openpgp: Fix test failure if compression features are disabled.
  * openpgp: Improve documentation regarding certificate expiry.
  * sq: fix requirement for bad signature to be _no_ output
  * sq: Make test more robust.
* Tue Dec 14 2021 Danilo Spinella <danilo.spinella@suse.com>
- Initial packaging of version 0.25.0
